@@ -1,15 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2012-2019 Snowflake Computing Inc. All right reserved.
-#
-
+# Copyright (c) 2012-2021 Snowflake Computing Inc. All right reserved.
 #
 # Python Db API v2
 #
-apilevel = '2.0'
+apilevel = "2.0"
 threadsafety = 2
-paramstyle = 'pyformat'
+paramstyle = "pyformat"
 
 import logging
 from logging import NullHandler
@@ -41,7 +39,7 @@ from .errors import (
     NotSupportedError,
     OperationalError,
     ProgrammingError,
-    Warning,
+    _Warning,
 )
 from .version import VERSION
 
@@ -54,37 +52,40 @@ def Connect(**kwargs):
 
 connect = Connect
 
-SNOWFLAKE_CONNECTOR_VERSION = '.'.join(str(v) for v in VERSION[0:3])
+SNOWFLAKE_CONNECTOR_VERSION = ".".join(str(v) for v in VERSION[0:3])
 __version__ = SNOWFLAKE_CONNECTOR_VERSION
 
 __all__ = [
     # Error handling
-    'Error', 'Warning',
-    'InterfaceError', 'DatabaseError',
-    'NotSupportedError', 'DataError', 'IntegrityError', 'ProgrammingError',
-    'OperationalError', 'InternalError',
-
+    "Error",
+    "_Warning",
+    "InterfaceError",
+    "DatabaseError",
+    "NotSupportedError",
+    "DataError",
+    "IntegrityError",
+    "ProgrammingError",
+    "OperationalError",
+    "InternalError",
     # Extended cursor
-    'DictCursor',
-
+    "DictCursor",
     # DBAPI PEP 249 required exports
-    'connect',
-    'apilevel',
-    'threadsafety',
-    'paramstyle',
-    'Date',
-    'Time',
-    'Timestamp',
-    'Binary',
-    'DateFromTicks',
-    'TimeFromTicks',
-    'TimestampFromTicks',
-    'STRING',
-    'BINARY',
-    'NUMBER',
-    'DATETIME',
-    'ROWID',
-
+    "connect",
+    "apilevel",
+    "threadsafety",
+    "paramstyle",
+    "Date",
+    "Time",
+    "Timestamp",
+    "Binary",
+    "DateFromTicks",
+    "TimeFromTicks",
+    "TimestampFromTicks",
+    "STRING",
+    "BINARY",
+    "NUMBER",
+    "DATETIME",
+    "ROWID",
     # Extended data type (experimental)
-    'Json',
+    "Json",
 ]
