@@ -40,19 +40,25 @@ log = logging.getLogger(__name__)
 
 def inject_into_urllib3():
     """Monkey-patch urllib3 with PyOpenSSL-backed SSL-support and OCSP."""
-    log.debug('Injecting ssl_wrap_socket_with_ocsp')
+    log.debug("Injecting ssl_wrap_socket_with_ocsp")
     connection_.ssl_wrap_socket = ssl_wrap_socket_with_ocsp
 
 
 @wraps(ssl_.ssl_wrap_socket)
 def ssl_wrap_socket_with_ocsp(*args, **kwargs):
     # Extract host_name
-    hostname_index = get_args(ssl_.ssl_wrap_socket).args.index('server_hostname')
-    server_hostname = args[hostname_index] if len(args) > hostname_index else kwargs.get('server_hostname', None)
+    hostname_index = get_args(ssl_.ssl_wrap_socket).args.index("server_hostname")
+    server_hostname = (
+        args[hostname_index]
+        if len(args) > hostname_index
+        else kwargs.get("server_hostname", None)
+    )
     # Remove context if present
-    ssl_context_index = get_args(ssl_.ssl_wrap_socket).args.index('ssl_context')
+    ssl_context_index = get_args(ssl_.ssl_wrap_socket).args.index("ssl_context")
     context_in_args = len(args) > ssl_context_index
-    ssl_context = args[hostname_index] if context_in_args else kwargs.get('ssl_context', None)
+    ssl_context = (
+        args[hostname_index] if context_in_args else kwargs.get("ssl_context", None)
+    )
     if not isinstance(ssl_context, PyOpenSSLContext):
         # Create new default context
         if context_in_args:
@@ -60,12 +66,12 @@ def ssl_wrap_socket_with_ocsp(*args, **kwargs):
             new_args[ssl_context_index] = None
             args = tuple(new_args)
         else:
-            del kwargs['ssl_context']
+            del kwargs["ssl_context"]
     # Fix ca certs location
-    ca_certs_index = get_args(ssl_.ssl_wrap_socket).args.index('ca_certs')
+    ca_certs_index = get_args(ssl_.ssl_wrap_socket).args.index("ca_certs")
     ca_certs_in_args = len(args) > ca_certs_index
-    if not ca_certs_in_args and not kwargs.get('ca_certs'):
-        kwargs['ca_certs'] = certifi.where()
+    if not ca_certs_in_args and not kwargs.get("ca_certs"):
+        kwargs["ca_certs"] = certifi.where()
 
     ret = ssl_.ssl_wrap_socket(*args, **kwargs)
 
@@ -74,35 +80,38 @@ def ssl_wrap_socket_with_ocsp(*args, **kwargs):
 
     from .ocsp_asn1crypto import SnowflakeOCSPAsn1Crypto as SFOCSP
 
-    log.debug('OCSP Mode: %s, '
-              'OCSP response cache file name: %s',
-              FEATURE_OCSP_MODE.name,
-              FEATURE_OCSP_RESPONSE_CACHE_FILE_NAME)
+    log.debug(
+        "OCSP Mode: %s, " "OCSP response cache file name: %s",
+        FEATURE_OCSP_MODE.name,
+        FEATURE_OCSP_RESPONSE_CACHE_FILE_NAME,
+    )
     if FEATURE_OCSP_MODE != OCSPMode.INSECURE:
         v = SFOCSP(
             ocsp_response_cache_uri=FEATURE_OCSP_RESPONSE_CACHE_FILE_NAME,
-            use_fail_open=FEATURE_OCSP_MODE == OCSPMode.FAIL_OPEN
+            use_fail_open=FEATURE_OCSP_MODE == OCSPMode.FAIL_OPEN,
         ).validate(server_hostname, ret.connection)
         if not v:
             raise OperationalError(
                 msg=(
-                    'The certificate is revoked or '
-                    'could not be validated: hostname={}'.format(
-                        server_hostname)),
-                errno=ER_OCSP_RESPONSE_CERT_STATUS_REVOKED)
+                    "The certificate is revoked or "
+                    "could not be validated: hostname={}".format(server_hostname)
+                ),
+                errno=ER_OCSP_RESPONSE_CERT_STATUS_REVOKED,
+            )
     else:
-        log.info('THIS CONNECTION IS IN INSECURE '
-                 'MODE. IT MEANS THE CERTIFICATE WILL BE '
-                 'VALIDATED BUT THE CERTIFICATE REVOCATION '
-                 'STATUS WILL NOT BE CHECKED.')
+        log.info(
+            "THIS CONNECTION IS IN INSECURE "
+            "MODE. IT MEANS THE CERTIFICATE WILL BE "
+            "VALIDATED BUT THE CERTIFICATE REVOCATION "
+            "STATUS WILL NOT BE CHECKED."
+        )
 
     return ret
 
 
-def _openssl_connect(hostname: str,
-                     port: int = 443,
-                     max_retry: int = 20,
-                     timeout: Optional[int] = None) -> OpenSSL.SSL.Connection:
+def _openssl_connect(
+    hostname: str, port: int = 443, max_retry: int = 20, timeout: Optional[int] = None
+) -> OpenSSL.SSL.Connection:
     """The OpenSSL connection without validating certificates.
 
     This is used to diagnose SSL issues.
@@ -118,10 +127,13 @@ def _openssl_connect(hostname: str,
                 context.set_timeout(timeout)
             client_ssl = OpenSSL.SSL.Connection(context, client)
             client_ssl.set_connect_state()
-            client_ssl.set_tlsext_host_name(hostname.encode('utf-8'))
+            client_ssl.set_tlsext_host_name(hostname.encode("utf-8"))
             client_ssl.do_handshake()
             return client_ssl
-        except (OpenSSL.SSL.SysCallError, ConnectionRefusedError, TimeoutError, OSError) as ex:
+        except (
+            OpenSSL.SSL.SysCallError,
+            OSError,
+        ) as ex:
             err = ex
             sleeping_time = min(sleeping_time * 2, 16)
             time.sleep(sleeping_time)
